==> huaweicloudsdker-3.1.76-py2.py3-none-any.whl: huaweicloudsdker/v3/model/export_route_policy.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExportRoutePolicy:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'export_policy_id': 'str'
    }

    attribute_map = {
        'export_policy_id': 'export_policy_id'
    }

    def __init__(self, export_policy_id=None):
        """ExportRoutePolicy

        The model defined in huaweicloud sdk

        :param export_policy_id: 出方向Ipv4协议路由策略id
        :type export_policy_id: str
        """
        
        

        self._export_policy_id = None
        self.discriminator = None

        if export_policy_id is not None:
            self.export_policy_id = export_policy_id

    @property
    def export_policy_id(self):
        """Gets the export_policy_id of this ExportRoutePolicy.

        出方向Ipv4协议路由策略id

        :return: The export_policy_id of this ExportRoutePolicy.
        :rtype: str
        """
        return self._export_policy_id

    @export_policy_id.setter
    def export_policy_id(self, export_policy_id):
        """Sets the export_policy_id of this ExportRoutePolicy.

        出方向Ipv4协议路由策略id

        :param export_policy_id: The export_policy_id of this ExportRoutePolicy.
        :type export_policy_id: str
        """
        self._export_policy_id = export_policy_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExportRoutePolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdker-3.1.154-py2.py3-none-any.whl: huaweicloudsdker/v3/model/export_route_policy.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ExportRoutePolicy:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'export_policy_id': 'str'
    }

    attribute_map = {
        'export_policy_id': 'export_policy_id'
    }

    def __init__(self, export_policy_id=None):
        r"""ExportRoutePolicy

        The model defined in huaweicloud sdk

        :param export_policy_id: 出方向Ipv4协议路由策略id
        :type export_policy_id: str
        """
        
        

        self._export_policy_id = None
        self.discriminator = None

        if export_policy_id is not None:
            self.export_policy_id = export_policy_id

    @property
    def export_policy_id(self):
        r"""Gets the export_policy_id of this ExportRoutePolicy.

        出方向Ipv4协议路由策略id

        :return: The export_policy_id of this ExportRoutePolicy.
        :rtype: str
        """
        return self._export_policy_id

    @export_policy_id.setter
    def export_policy_id(self, export_policy_id):
        r"""Sets the export_policy_id of this ExportRoutePolicy.

        出方向Ipv4协议路由策略id

        :param export_policy_id: The export_policy_id of this ExportRoutePolicy.
        :type export_policy_id: str
        """
        self._export_policy_id = export_policy_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExportRoutePolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
